.. image:: https://travis-ci.org/MacHu-GWU/crawl_redfin-project.svg?branch=master

.. image:: https://img.shields.io/pypi/v/crawl_redfin.svg

.. image:: https://img.shields.io/pypi/l/crawl_redfin.svg

.. image:: https://img.shields.io/pypi/pyversions/crawl_redfin.svg


Welcome to crawl_redfin Documentation
=====================================
Redfin Crawler Tool Set.


**Quick Links**
---------------
- `GitHub Homepage <https://github.com/MacHu-GWU/crawl_redfin-project>`_
- `Online Documentation <http://pythonhosted.org/crawl_redfin>`_
- `PyPI download <https://pypi.python.org/pypi/crawl_redfin>`_
- `Install <install_>`_
- `Issue submit and feature request <https://github.com/MacHu-GWU/crawl_redfin-project/issues>`_
- `API reference and source code <http://pythonhosted.org/crawl_redfin/py-modindex.html>`_


.. _install:

Install
-------

``crawl_redfin`` is released on PyPI, so all you need is:

.. code-block:: console

	$ pip install crawl_redfin

To upgrade to latest version:

.. code-block:: console

	$ pip install --upgrade crawl_redfin